@@ -23,7 +23,6 @@
 
 #include <QBoxLayout>
 #include <QLabel>
-#include <KDialog>
 #include <QListWidget>
 #include <KLocalizedString>
 Editor::Editor(const Kolf::ItemFactory& factory, QWidget *parent)
@@ -33,11 +32,8 @@ Editor::Editor(const Kolf::ItemFactory& factory, QWidget *parent)
 	config = 0;
 
 	hlayout = new QHBoxLayout(this);
-	hlayout->setMargin( KDialog::marginHint() );
-	hlayout->setSpacing( KDialog::spacingHint() );
 
 	QVBoxLayout *vlayout = new QVBoxLayout;
-	vlayout->setSpacing( KDialog::spacingHint() );
 	hlayout->addLayout( vlayout );
 	vlayout->addWidget(new QLabel(i18n("Add object:"), this));
 	m_typeList = new QListWidget(this);
@@ -51,7 +47,7 @@ Editor::Editor(const Kolf::ItemFactory& factory, QWidget *parent)
 		item->setData(Qt::UserRole, metadata.identifier);
 		m_typeList->addItem(item);
 	}
-	connect(m_typeList, SIGNAL(executed(QListWidgetItem*)), SLOT(listboxExecuted(QListWidgetItem*)));
+	connect(m_typeList, &QListWidget::itemClicked, this, &Editor::listboxExecuted);
 }
 
 void Editor::listboxExecuted(QListWidgetItem* item)
@@ -71,7 +67,7 @@ void Editor::setItem(CanvasItem *item)
 	config->setFrameStyle(QFrame::Box | QFrame::Raised);
 	config->setLineWidth(1);
 	config->show();
-	connect(config, SIGNAL(modified()), this, SIGNAL(changed()));
+	connect(config, &Config::modified, this, &Editor::changed);
 }
 
 
