@@ -20,18 +20,19 @@
 #include "objects.h"
 #include "ball.h"
 #include "game.h"
+#include "kolfNumInput.h"
 #include "tagaro/board.h"
 
 #include <QFormLayout>
 #include <QTimer>
 #include <KConfigGroup>
-#include <KNumInput>
+#include <KPluralHandlingSpinBox>
 #include <KRandom>
 #include <KLocalizedString>
 //BEGIN Kolf::BlackHole
 
 Kolf::BlackHole::BlackHole(QGraphicsItem* parent, b2World* world)
-	: EllipticalCanvasItem(true, QLatin1String("black_hole"), parent, world)
+	: EllipticalCanvasItem(true, QStringLiteral("black_hole"), parent, world)
 	, m_minSpeed(3.0)
 	, m_maxSpeed(5.0)
 	, m_runs(0)
@@ -157,7 +158,7 @@ bool Kolf::BlackHole::collision(Ball* ball)
 	if (m_runs > 10 && game && game->isInPlay())
 		return true;
 
-	playSound("blackholeputin");
+	game->playSound(Sound::BlackHolePutIn);
 
 	const double diff = m_maxSpeed - m_minSpeed;
 	const double newSpeed = m_minSpeed + speed / 3.75 * diff;
@@ -170,18 +171,18 @@ bool Kolf::BlackHole::collision(Ball* ball)
 	const double distance = Vector(pos() - m_exitItem->pos()).magnitude();
 	BlackHoleTimer* timer = new BlackHoleTimer(ball, newSpeed, distance * 2.5 - newSpeed * 35 + 500);
 
-	connect(timer, SIGNAL(eject(Ball*,double)), this, SLOT(eject(Ball*,double)));
-	connect(timer, SIGNAL(halfway()), this, SLOT(halfway()));
+	connect(timer, &BlackHoleTimer::eject, this, &Kolf::BlackHole::eject);
+	connect(timer, &BlackHoleTimer::halfway, this, &Kolf::BlackHole::halfway);
 
-	playSound("blackhole");
+	game->playSound(Sound::BlackHole);
 	return false;
 }
 
 Kolf::BlackHoleTimer::BlackHoleTimer(Ball* ball, double speed, int msec)
 	: m_speed(speed), m_ball(ball)
 {
-	QTimer::singleShot(msec, this, SLOT(emitEject()));
-	QTimer::singleShot(msec / 2, this, SIGNAL(halfway()));
+	QTimer::singleShot(msec, this, &Kolf::BlackHoleTimer::emitEject);
+	QTimer::singleShot(msec / 2, this, &Kolf::BlackHoleTimer::halfway);
 }
 
 void Kolf::BlackHoleTimer::emitEject()
@@ -203,12 +204,12 @@ void Kolf::BlackHole::eject(Ball* ball, double speed)
 
 	m_runs++;
 
-	playSound("blackholeeject");
+	game->playSound(Sound::BlackHoleEject);
 }
 
 void Kolf::BlackHole::halfway()
 {
-	playSound("blackhole");
+	game->playSound(Sound::BlackHole);
 }
 
 void Kolf::BlackHole::load(KConfigGroup* cfgGroup)
@@ -236,28 +237,28 @@ Kolf::BlackHoleConfig::BlackHoleConfig(BlackHole* blackHole, QWidget* parent)
 {
 	QFormLayout* layout = new QFormLayout(this);
 
-	KIntSpinBox* deg = new KIntSpinBox(this);
+	KPluralHandlingSpinBox* deg = new KPluralHandlingSpinBox(this);
 	deg->setRange(0, 359);
 	deg->setSingleStep(10);
 	deg->setSuffix(ki18np(" degree", " degrees"));
 	deg->setValue(m_blackHole->curExitDeg());
 	deg->setWrapping(true);
 	layout->addRow(i18n("Exiting ball angle:"), deg);
-	connect(deg, SIGNAL(valueChanged(int)), this, SLOT(degChanged(int)));
+	connect(deg, QOverload<int>::of(&KPluralHandlingSpinBox::valueChanged), this, &Kolf::BlackHoleConfig::degChanged);
 
-	KDoubleNumInput* min = new KDoubleNumInput(this);
+	kolfDoubleNumInput* min = new kolfDoubleNumInput(this);
 	min->setSizePolicy(QSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed));
 	min->setRange(0, 8);
 	min->setValue(m_blackHole->minSpeed());
 	layout->addRow(i18n("Minimum exit speed:"), min);
-	connect(min, SIGNAL(valueChanged(double)), this, SLOT(minChanged(double)));
+	connect(min, &kolfDoubleNumInput::valueChanged, this, &Kolf::BlackHoleConfig::minChanged);
 
-	KDoubleNumInput* max = new KDoubleNumInput(this);
+	kolfDoubleNumInput* max = new kolfDoubleNumInput(this);
 	max->setSizePolicy(QSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed));
 	max->setRange(0, 8);
 	max->setValue(m_blackHole->maxSpeed());
 	layout->addRow(i18n("Maximum exit speed:"), max);
-	connect(max, SIGNAL(valueChanged(double)), this, SLOT(maxChanged(double)));
+	connect(max, &kolfDoubleNumInput::valueChanged, this, &Kolf::BlackHoleConfig::maxChanged);
 }
 
 void Kolf::BlackHoleConfig::degChanged(int newdeg)
@@ -290,8 +291,8 @@ Kolf::BlackHoleOverlay::BlackHoleOverlay(Kolf::BlackHole* blackHole)
 	addHandle(m_exitIndicator);
 	addHandle(m_exitHandle);
 	addHandle(m_speedHandle);
-	connect(m_exitHandle, SIGNAL(moveRequest(QPointF)), this, SLOT(moveHandle(QPointF)));
-	connect(m_speedHandle, SIGNAL(moveRequest(QPointF)), this, SLOT(moveHandle(QPointF)));
+	connect(m_exitHandle, &Kolf::OverlayHandle::moveRequest, this, &Kolf::BlackHoleOverlay::moveHandle);
+	connect(m_speedHandle, &Kolf::OverlayHandle::moveRequest, this, &Kolf::BlackHoleOverlay::moveHandle);
 }
 
 void Kolf::BlackHoleOverlay::update()
@@ -323,7 +324,7 @@ void Kolf::BlackHoleOverlay::moveHandle(const QPointF& handleScenePos)
 //BEGIN Kolf::Cup
 
 Kolf::Cup::Cup(QGraphicsItem* parent, b2World* world)
-	: EllipticalCanvasItem(false, QLatin1String("cup"), parent, world)
+	: EllipticalCanvasItem(false, QStringLiteral("cup"), parent, world)
 {
 	const int diameter = 16;
 	setSize(QSizeF(diameter, diameter));
@@ -347,7 +348,7 @@ bool Kolf::Cup::collision(Ball* ball)
 		return true;
 	//place ball in hole
 	ball->setState(Holed);
-	playSound("holed");
+	game->playSound(Sound::Holed);
 	ball->setPos(pos());
 	ball->setVelocity(Vector());
 	return false;
